@@ -62,13 +62,13 @@ class BaseDirective(rst.Directive):
         self.filter_factory = filter_factory
         self.target_handler_factory = target_handler_factory
 
-    def render(self, data_object, project_info, filter_, target_handler, mask_factory):
+    def render(self, data_object, project_info, options, filter_, target_handler, mask_factory):
         "Standard render process used by subclasses"
 
         renderer_factory_creator = self.renderer_factory_creator_constructor.create_factory_creator(
             project_info,
             self.state.document,
-            self.options,
+            options,
             target_handler
             )
 
@@ -80,10 +80,10 @@ class BaseDirective(rst.Directive):
                 filter_,
                 target_handler,
                 )
-        except ParserError, e:
+        except ParserError as e:
             return format_parser_error("doxygenclass", e.error, e.filename, self.state,
                                        self.lineno, True)
-        except FileIOError, e:
+        except FileIOError as e:
             return format_parser_error("doxygenclass", e.error, e.filename, self.state, self.lineno)
 
         context = RenderContext([data_object, self.root_data_object], mask_factory)
@@ -114,7 +114,7 @@ class DoxygenBaseDirective(BaseDirective):
 
         try:
             project_info = self.project_info_factory.create_project_info(self.options)
-        except ProjectError, e:
+        except ProjectError as e:
             warning = create_warning(None, self.state, self.lineno)
             return warning.warn('doxygen%s: %s' % (self.kind, e))
 
@@ -124,7 +124,7 @@ class DoxygenBaseDirective(BaseDirective):
 
         try:
             data_object = finder.find_one(matcher_stack)
-        except NoMatchesError, e:
+        except NoMatchesError as e:
             display_name = "%s::%s" % (namespace, name) if namespace else name
             warning = create_warning(project_info, self.state, self.lineno, name=display_name,
                                      kind=self.kind)
@@ -135,5 +135,6 @@ class DoxygenBaseDirective(BaseDirective):
         filter_ = self.filter_factory.create_outline_filter(self.options)
 
         mask_factory = NullMaskFactory()
-        return self.render(data_object, project_info, filter_, target_handler, mask_factory)
+        return self.render(data_object, project_info, self.options, filter_, target_handler,
+                           mask_factory)
 
