@@ -73,18 +73,22 @@ class CompoundDefTypeSubRenderer(Renderer):
 
         # Get all sub sections
         for sectiondef in self.data_object.sectiondef:
-            kind = sectiondef.kind
-            node = self.node_factory.desc()
-            node.document = self.state.document
-            node['objtype'] = kind
             context = self.context.create_child_context(sectiondef)
             renderer = self.renderer_factory.create_renderer(context)
-            node.extend(renderer.render())
-            try:
-                # As "user-defined" can repeat
-                section_nodelists[kind] += [node]
-            except KeyError:
-                section_nodelists[kind] = [node]
+            child_nodes = renderer.render()
+            if not child_nodes:
+                # Skip empty section
+                continue
+            kind = sectiondef.kind
+            node = self.node_factory.container(classes=['breathe-sectiondef'])
+            node.document = self.state.document
+            node['objtype'] = kind
+            node.extend(child_nodes)
+            # We store the nodes as a list against the kind in a dictionary as the kind can be
+            # 'user-edited' and that can repeat so this allows us to collect all the 'user-edited'
+            # entries together
+            nodes = section_nodelists.setdefault(kind, [])
+            nodes += [node]
 
         # Order the results in an appropriate manner
         for kind, _ in self.sections:
@@ -125,9 +129,6 @@ class SectionDefTypeSubRenderer(Renderer):
 
         if node_list:
 
-            contentnode = self.node_factory.desc_content()
-            contentnode.extend(node_list)
-
             text = self.section_titles[self.data_object.kind]
 
             # Override default name for user-defined sections. Use "Unnamed
@@ -139,12 +140,12 @@ class SectionDefTypeSubRenderer(Renderer):
                     text = self.data_object.header
                 else:
                     text = "Unnamed Group"
-            title = self.node_factory.emphasis(text=text)
 
-            signode = self.node_factory.desc_signature()
-            signode.append(title)
+            # Use rubric for the title because, unlike the docutils element "section",
+            # it doesn't interfere with the document structure.
+            rubric = self.node_factory.rubric(text=text, classes=['breathe-sectiondef-title'])
 
-            return [signode, contentnode]
+            return [rubric] + node_list
 
         return []
 
@@ -203,16 +204,24 @@ class MemberDefTypeSubRenderer(Renderer):
 
         return nodes
 
+    def build_signodes(self, targets):
+        """Returns a list to account for when we need multiple signature nodes to account for
+        multi-line declarations like templated declarations"""
+
+        # Build title nodes
+        signode = self.node_factory.desc_signature()
+        signode.extend(targets)
+        signode.extend(self.title())
+        return [signode]
 
     def render(self):
 
         # Build targets for linking
-        signode = self.node_factory.desc_signature()
-        signode.extend(self.create_domain_target())
-        signode.extend(self.create_doxygen_target())
+        targets = []
+        targets.extend(self.create_domain_target())
+        targets.extend(self.create_doxygen_target())
 
-        # Build title nodes
-        signode.extend(self.title())
+        signodes = self.build_signodes(targets)
 
         # Build description nodes
         contentnode = self.node_factory.desc_content()
@@ -221,7 +230,7 @@ class MemberDefTypeSubRenderer(Renderer):
         node = self.node_factory.desc()
         node.document = self.state.document
         node['objtype'] = self.data_object.kind
-        node.append(signode)
+        node.extend(signodes)
         node.append(contentnode)
 
         return [node]
@@ -233,9 +242,10 @@ class FuncMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
 
         return self.domain_handler.create_function_target(self.data_object)
 
-    def title(self):
+    def build_signodes(self, targets):
 
-        nodes = []
+        signodes = []
+        title_signode = self.node_factory.desc_signature()
 
         # Handle any template information
         if self.data_object.templateparamlist:
@@ -244,7 +254,23 @@ class FuncMemberDefTypeSubRenderer(MemberDefTypeSubRenderer):
             template_nodes = [self.node_factory.Text("template <")]
             template_nodes.extend(renderer.render())
             template_nodes.append(self.node_factory.Text("> "))
-            nodes.append(self.node_factory.line("", *template_nodes))
+            template_signode = self.node_factory.desc_signature()
+            # Add targets to the template line if it is there
+            template_signode.extend(targets)
+            template_signode.extend(template_nodes)
+            signodes.append(template_signode)
+
+        else:
+            # Add targets to title line if there is no template line
+            title_signode.extend(targets)
+
+        title_signode.extend(self.title())
+        signodes.append(title_signode)
+        return signodes
+
+    def title(self):
+
+        nodes = []
 
         # Note whether a member function is virtual
         if self.data_object.virt != 'non-virtual':
@@ -455,6 +481,10 @@ class ParamTypeSubRenderer(Renderer):
             if nodelist: nodelist.append(self.node_factory.Text(" "))
             nodelist.append(self.node_factory.emphasis(text=self.data_object.defname))
 
+        # array information
+        if self.data_object.array:
+            nodelist.append(self.node_factory.Text(self.data_object.array))
+
         # Default value
         if self.data_object.defval:
             nodelist.append(self.node_factory.Text(" = "))
@@ -1018,3 +1048,16 @@ class DocHeadingTypeSubRenderer(Renderer):
 
         return [self.node_factory.emphasis("", "", *nodelist)]
 
+
+class DocURLLinkSubRenderer(Renderer):
+    """Url Link Renderer"""
+
+    def render(self):
+
+        nodelist = []
+        for item in self.data_object.content_:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
+            nodelist.extend(renderer.render())
+
+        return [self.node_factory.reference("", "", refuri=self.data_object.url, *nodelist)]
